@@ -103,11 +103,9 @@ class _Regressor(object):
             return regressor_obj
 
     @staticmethod
-    def get_defaults(raster=None,
-                     **kwargs):
+    def get_defaults(**kwargs):
         """
         Method to define default parameters for regressor
-        :param raster: Raster object (see geosoup.Raster)
         :param kwargs: Keyword arguments
         """
 
@@ -118,7 +116,7 @@ class _Regressor(object):
             'llim': 0.025,
             'variance_limit': 0.05,
             'min_rsq_limit': 60.0,
-            'n_random': 5,
+            'n_rand': 5,
             'uncert_dict': {},
             'half_range': True,
             'tile_size': 512,
@@ -137,7 +135,9 @@ class _Regressor(object):
 
         defaults.update(kwargs)
 
-        if raster is not None:
+        if 'raster' in kwargs and type(kwargs['raster']) == Raster:
+            raster = kwargs['raster']
+
             if not raster.init:
                 raster.initialize()
 
@@ -243,7 +243,7 @@ class _Regressor(object):
         kwargs.update({'out_data_type':
                        gdal_array.NumericTypeCodeToGDALTypeCode(regressor.data['labels'].dtype)})
 
-        defaults = _Regressor.get_defaults(raster_obj,
+        defaults = _Regressor.get_defaults(raster=raster_obj,
                                            **kwargs)
 
         output_type = defaults['output_type'] if output_type is None else output_type
@@ -1022,7 +1022,7 @@ class RFRegressor(_Regressor):
         :return: range of uncertainty values if one or more uncertainty bands
                  are specified in uncertainty dict else returns 0
         """
-        defaults = _Regressor.get_defaults(kwargs)
+        defaults = _Regressor.get_defaults(**kwargs)
 
         uncert_dict = defaults['uncert_dict']
         regressor = defaults['regressor']
@@ -1030,8 +1030,9 @@ class RFRegressor(_Regressor):
         if uncert_dict is None or len(uncert_dict) == 0:
             raise RuntimeError("No uncertainty band dictionary provided")
 
-        if regressor is None:
-            raise RuntimeError("Regressor must be supplied to calculate uncertainty ranges")
+        if type(regressor) != _Regressor:
+            raise RuntimeError("Regressor must be supplied to calculate uncertainty ranges" +
+                               "Regressor must be of _Regressor class")
 
         n_rand = defaults['n_rand']
         output_type = defaults['output_type']
@@ -1119,7 +1120,7 @@ class RFRegressor(_Regressor):
                            False  - full range (x +/- a), or
                            True   - half range (x +/- a/2)
         """
-        defaults = self.get_defaults(kwargs)
+        defaults = self.get_defaults(**kwargs)
 
         output_type = defaults['output_type'] \
             if output_type is None else output_type
@@ -1350,7 +1351,7 @@ class RFRegressor(_Regressor):
                'var_y': Boolean (if variance of leaf nodes should be calculated)
                'sd_y': Boolean (if the standard dev of all values at a leaf should be calculated)
         """
-        defaults = self.get_defaults(kwargs)
+        defaults = self.get_defaults(**kwargs)
 
         output_type = defaults['output_type'] \
             if output_type is None else output_type
